@@ -197,7 +197,7 @@ class PredefinedWavelengths:
                                 1.14200000e-03, 6.77000000e-04, 3.55000000e-04,
                                 1.12000000e-04]))
 
-    LANDSAT_OLI_B7 = (8, 2.037, 2.354,
+    LANDSAT_OLI_B8 = (8, 2.037, 2.354,
                       np.array([0, 1.07000000e-04, 2.40000000e-04,
                                 3.99000000e-04, 5.99000000e-04, 8.80500000e-04,
                                 1.22200000e-03, 1.64550000e-03, 2.18700000e-03,
@@ -272,6 +272,142 @@ class PredefinedWavelengths:
                                  1.51780000e-02, 6.70950000e-03, 3.22000000e-03,
                                  1.21200000e-03]))
 
+    # RapidEye
+    # Taken from http://blackbridge.com/rapideye/upload/Spectral_Response_Curves.pdf
+    # Interpolated to 2.5nm intervals, as required by 6S
+    RAPIDEYE_B1 = (10, 0.420, 0.514,
+                    np.array([ 0.002 ,  0.    ,  0.    ,  0.0015,  0.    ,  0.    ,  0.001 ,
+                            0.0095,  0.321 ,  0.725 ,  0.74  ,  0.759 ,  0.77  ,  0.781 ,
+                            0.784 ,  0.7935,  0.796 ,  0.8005,  0.806 ,  0.804 ,  0.807 ,
+                            0.817 ,  0.82  ,  0.8275,  0.84  ,  0.847 ,  0.862 ,  0.8765,
+                            0.886 ,  0.9105,  0.928 ,  0.9415,  0.969 ,  0.9685,  1.    ,
+                            0.9875,  0.437 ,  0.019, 0.0]))
+
+    RAPIDEYE_B2 = (11, 0.462, 0.595,
+                    np.array([ 0.002 ,  0.0025,  0.002 ,  0.021 ,  0.    ,  0.    ,  0.    ,
+                            0.    ,  0.    ,  0.    ,  0.    ,  0.0145,  0.    ,  0.    ,
+                            0.    ,  0.    ,  0.    ,  0.    ,  0.    ,  0.001 ,  0.002 ,
+                            0.01  ,  0.054 ,  0.4055,  0.868 ,  0.866 ,  0.877 ,  0.872 ,
+                            0.874 ,  0.8815,  0.882 ,  0.8805,  0.886 ,  0.8955,  0.899 ,
+                            0.8995,  0.91  ,  0.922 ,  0.928 ,  0.9345,  0.946 ,  0.9525,
+                            0.96  ,  0.972 ,  0.976 ,  0.975 ,  0.989 ,  0.9905,  0.984 ,
+                            0.997 ,  0.97  ,  0.6535,  0.039 ,  0.004 ]))
+
+    RAPIDEYE_B3 = (12, 0.486, 0.691,
+                    np.array([  2.00000000e-03,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             1.00000000e-03,   5.00000000e-04,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   5.00000000e-04,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   5.00000000e-04,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             1.00000000e-03,   4.00000000e-03,   1.80000000e-02,
+                             1.43000000e-01,   7.23000000e-01,   8.57500000e-01,
+                             8.65000000e-01,   8.81500000e-01,   8.82000000e-01,
+                             8.93000000e-01,   9.07000000e-01,   9.12500000e-01,
+                             9.18000000e-01,   9.31000000e-01,   9.44000000e-01,
+                             9.52500000e-01,   9.61000000e-01,   9.67000000e-01,
+                             9.73000000e-01,   9.83000000e-01,   9.91000000e-01,
+                             9.87000000e-01,   9.89000000e-01,   9.99000000e-01,
+                             9.81000000e-01,   9.28500000e-01,   1.74000000e-01,
+                             1.70000000e-02, 0.0]))
+
+    RAPIDEYE_B4 = (13, 0.500, 0.740,
+                    np.array([  2.70000000e-02,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   5.00000000e-04,
+                             0.00000000e+00,   5.00000000e-04,   1.00000000e-03,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   5.00000000e-04,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   2.20000000e-02,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   5.00000000e-04,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   1.00000000e-03,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   1.00000000e-03,
+                             2.00000000e-03,   5.50000000e-03,   2.10000000e-02,
+                             1.08500000e-01,   4.91000000e-01,   9.49000000e-01,
+                             9.98000000e-01,   9.99500000e-01,   9.98000000e-01,
+                             9.91500000e-01,   9.87000000e-01,   9.85500000e-01,
+                             9.82000000e-01,   9.74000000e-01,   9.66000000e-01,
+                             9.64000000e-01,   9.61000000e-01,   9.45500000e-01,
+                             9.39000000e-01,   8.98000000e-01,   4.25000000e-01,
+                             9.40000000e-02,   2.00000000e-02,   5.50000000e-03, 0.0]))
+
+    RAPIDEYE_B5 = (14, 0.519, 0.866,
+                    np.array([  2.00000000e-03,   5.00000000e-04,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   1.00000000e-03,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   2.00000000e-03,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   1.00000000e-03,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   4.00000000e-03,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             1.00000000e-03,   2.00000000e-03,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   1.00000000e-03,   2.00000000e-03,
+                             5.00000000e-04,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   5.00000000e-04,   2.20000000e-02,
+                             5.00000000e-04,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
+                             0.00000000e+00,   1.00000000e-03,   1.00000000e-03,
+                             2.00000000e-03,   4.50000000e-03,   9.00000000e-03,
+                             1.95000000e-02,   4.60000000e-02,   1.27500000e-01,
+                             3.45000000e-01,   7.49000000e-01,   9.88000000e-01,
+                             9.88000000e-01,   9.69000000e-01,   9.71500000e-01,
+                             9.81000000e-01,   9.82000000e-01,   9.74000000e-01,
+                             9.65000000e-01,   9.60000000e-01,   9.57500000e-01,
+                             9.59000000e-01,   9.59000000e-01,   9.57000000e-01,
+                             9.54500000e-01,   9.50000000e-01,   9.45000000e-01,
+                             9.39000000e-01,   9.34000000e-01,   9.29000000e-01,
+                             9.27000000e-01,   9.26000000e-01,   9.26000000e-01,
+                             9.25000000e-01,   9.19500000e-01,   9.11000000e-01,
+                             9.00000000e-01,   8.91000000e-01,   8.85500000e-01,
+                             8.83000000e-01,   8.78000000e-01,   8.65000000e-01,
+                             8.45500000e-01,   8.38000000e-01,   8.37000000e-01,
+                             7.12000000e-01,   3.63000000e-01,   1.24000000e-01,
+                             4.30000000e-02,   1.60000000e-02,   7.00000000e-03,
+                             3.00000000e-03], ))
+
+
+
     # All of the original predefined wavelengths from 6S
     # CONSTANT_NAME = (ID for Constant, Start Wavelength, End Wavelength)
     METEOSAT_VISIBLE = (-2, 0.35, 1.11)
