@@ -17,10 +17,10 @@
 
 """Contains a number of classes for helper methods"""
 
-from .all_angles import *
-from .all_wavelengths import *
-from .radiosonde import *
-from .aeronet import *
-from .spectra import Spectra
+from all_angles import *
+from all_wavelengths import *
+from radiosonde import *
+from aeronet import *
+from spectra import Spectra
 
-__all__ = ["Angles", "Wavelengths", "Radiosonde", "Aeronet", "Spectra"]
\ No newline at end of file
+__all__ = ["Angles", "Wavelengths", "Radiosonde", "Aeronet", "Spectra"]
